@@ -520,7 +520,7 @@ static struct net_device *epic_probe1(int pci_bus, int pci_devfn,
 	dev->get_stats = &epic_get_stats;
 	dev->set_multicast_list = &set_rx_mode;
 	dev->do_ioctl = &mii_ioctl;
-#ifdef HAVE_NETIF_QUEUE
+#ifdef HAVE_TX_TIMEOUT
 	dev->watchdog_timeo = TX_TIMEOUT;
 	dev->tx_timeout = epic_tx_timeout;
 #endif
@@ -1185,6 +1185,8 @@ static int epic_close(struct net_device *dev)
 
 	epic_pause(dev);
 	del_timer(&ep->timer);
+	/* Disable interrupts by clearing the interrupt mask. */
+	outl(0, ioaddr + INTMASK);
 	free_irq(dev->irq, dev);
 
 	/* Free all the skbuffs in the Rx queue. */
