@@ -62,7 +62,6 @@
 #include <linux/malloc.h>
 #include <linux/string.h>
 #include <linux/timer.h>
-#include <linux/delay.h>
 #include <linux/module.h>
 #include <asm/io.h>
 #include <asm/system.h>
@@ -141,8 +140,6 @@ static dev_link_t *dev_list = NULL;
 extern int ibmtr_probe(struct net_device *dev);
 extern int trdev_init(struct net_device *dev);
 extern void tok_interrupt(int irq, struct pt_regs *regs);
-extern int tok_init_card(struct net_device *dev);
-extern unsigned char get_sram_size(struct tok_info *ti);
 
 /*====================================================================*/
 
@@ -306,8 +303,10 @@ static void ibmtr_detach(dev_link_t *link)
 
     /* Unlink device structure, free bits */
     *linkp = link->next;
-    if (link->dev)
+    if (info->dev) {
 	unregister_trdev(info->dev);
+	kfree(info->dev);
+    }
     kfree(info);
 
 } /* ibmtr_detach */
@@ -541,6 +540,9 @@ static int ibmtr_event(event_t event, int priority,
 
 static void ibmtr_hw_setup(struct net_device *dev, u_int mmiobase)
 {
+#if (LINUX_VERSION_CODE < VERSION(2,2,0)) 
+    struct tok_info *ti = dev->priv;
+#endif
     int i;
 
     /* Bizarre IBM behavior, there are 16 bits of information we
