@@ -7,7 +7,7 @@
     card's attribute and common memory.  It includes character
     and block device support.
 
-    memory_cs.c 1.71 2000/06/09 22:15:05
+    memory_cs.c 1.76 2000/08/22 04:38:30
 
     The contents of this file are subject to the Mozilla Public
     License Version 1.1 (the "License"); you may not use this file
@@ -20,7 +20,7 @@
     rights and limitations under the License.
 
     The initial developer of the original code is David A. Hinds
-    <dhinds@pcmcia.sourceforge.org>.  Portions created by David A. Hinds
+    <dahinds@users.sourceforge.net>.  Portions created by David A. Hinds
     are Copyright (C) 1999 David A. Hinds.  All Rights Reserved.
 
     Alternatively, the contents of this file may be used under the
@@ -91,7 +91,7 @@ static int pc_debug = PCMCIA_DEBUG;
 MODULE_PARM(pc_debug, "i");
 #define DEBUG(n, args...) if (pc_debug>(n)) printk(KERN_DEBUG args)
 static char *version =
-"memory_cs.c 1.71 2000/06/09 22:15:05 (David Hinds)";
+"memory_cs.c 1.76 2000/08/22 04:38:30 (David Hinds)";
 #else
 #define DEBUG(n, args...)
 #endif
@@ -143,6 +143,7 @@ typedef struct minor_dev_t {		/* For normal regions */
     region_info_t	region;
     memory_handle_t	handle;
     int			open;
+    u_int		offset;
 } minor_dev_t;
 
 typedef struct direct_dev_t {		/* For direct access */
@@ -151,6 +152,7 @@ typedef struct direct_dev_t {		/* For direct access */
     caddr_t		Base;
     u_int		Size;
     u_int		cardsize;
+    u_int		offset;
 } direct_dev_t;
 
 typedef struct memory_dev_t {
@@ -331,6 +333,9 @@ static void memory_detach(dev_link_t *link)
     
 ======================================================================*/
 
+#define WIN_TYPE(a)  ((a) ? WIN_MEMORY_TYPE_AM : WIN_MEMORY_TYPE_CM)
+#define WIN_WIDTH(w) ((w) ? WIN_DATA_WIDTH_16 : WIN_DATA_WIDTH_8)
+
 static u_int get_size(dev_link_t *link, direct_dev_t *direct)
 {
     modwin_t mod;
@@ -407,10 +412,7 @@ static void memory_config(dev_link_t *link)
 	if (dev_table[nd] == link) break;
     
     /* Allocate a small memory window for direct access */
-    if (word_width)
-	req.Attributes = WIN_DATA_WIDTH_16;
-    else
-	req.Attributes = WIN_DATA_WIDTH_8;
+    req.Attributes = WIN_WIDTH(word_width);
     req.Base = req.Size = 0;
     req.AccessSpeed = mem_speed;
     link->win = (window_handle_t)link->handle;
@@ -425,8 +427,7 @@ static void memory_config(dev_link_t *link)
     for (attr = 0; attr < 2; attr++) {
 	nr[attr] = 0;
 	minor = dev->minor + attr*MAX_PART;
-	region.Attributes =
-	    (attr) ? REGION_TYPE_AM : REGION_TYPE_CM;
+	region.Attributes = (attr) ? REGION_TYPE_AM : REGION_TYPE_CM;
 	ret = CardServices(GetFirstRegion, link->handle, &region);
 	while (ret == CS_SUCCESS) {
 	    minor->region = region;
@@ -440,7 +441,28 @@ static void memory_config(dev_link_t *link)
     dev->node.minor = MINOR_NR(nd, 0, 0, 0);
     link->dev = &dev->node;
     link->state &= ~DEV_CONFIG_PENDING;
-    
+
+#ifdef CISTPL_FORMAT_MEM
+    /* This is a hack, not a complete solution */
+    {
+	tuple_t tuple;
+	cisparse_t parse;
+	u_char buf[64];
+	tuple.Attributes = 0;
+	tuple.TupleData = (cisdata_t *)buf;
+	tuple.TupleDataMax = sizeof(buf);
+	tuple.TupleOffset = 0;
+	tuple.DesiredTuple = CISTPL_FORMAT;
+	if (CardServices(GetFirstTuple, link->handle, &tuple)
+	    == CS_SUCCESS) {
+	    CS_CHECK(GetTupleData, link->handle, &tuple);
+	    CS_CHECK(ParseTuple, link->handle, &tuple, &parse);
+	    dev->direct.offset = dev->minor[0].offset =
+		parse.format.offset;
+	}
+    }
+#endif
+
     printk(KERN_INFO "memory_cs: mem%d:", nd);
     if ((nr[0] == 0) && (nr[1] == 0)) {
 	cisinfo_t cisinfo;
@@ -685,8 +707,6 @@ static ssize_t direct_read FOPS(struct inode *inode,
     direct = &dev->direct;
     
     /* Boundary checks */
-    if (count < 0)
-	return -EINVAL;
     pos = FPOS;
     size = (IS_DIRECT(minor)) ? HIGH_ADDR : direct->cardsize;
     if (pos >= size)
@@ -694,8 +714,8 @@ static ssize_t direct_read FOPS(struct inode *inode,
     if (count > size - pos)
 	count = size - pos;
 
-    mod.Attributes = WIN_ENABLE;
-    mod.Attributes |= (REGION_AM(minor)) ? WIN_MEMORY_TYPE_AM : 0;
+    mod.Attributes = WIN_ENABLE | WIN_TYPE(REGION_AM(minor));
+    mod.Attributes |= WIN_WIDTH(word_width);
     mod.AccessSpeed = mem_speed;
     ret = CardServices(ModifyWindow, link->win, &mod);
     if (ret != CS_SUCCESS) {
@@ -835,8 +855,6 @@ static ssize_t direct_write FOPS(struct inode *inode,
 	return -EROFS;
 
     /* Boundary checks */
-    if (count < 0)
-	return -EINVAL;
     size = (IS_DIRECT(minor)) ? HIGH_ADDR : direct->cardsize;
     pos = FPOS;
     if (pos >= size)
@@ -844,8 +862,8 @@ static ssize_t direct_write FOPS(struct inode *inode,
     if (count > size - pos)
 	count = size - pos;
 
-    mod.Attributes = WIN_ENABLE;
-    mod.Attributes |= (REGION_AM(minor)) ? WIN_MEMORY_TYPE_AM : 0;
+    mod.Attributes = WIN_ENABLE | WIN_TYPE(REGION_AM(minor));
+    mod.Attributes |= WIN_WIDTH(word_width);
     mod.AccessSpeed = mem_speed;
     ret = CardServices(ModifyWindow, link->win, &mod);
     if (ret != CS_SUCCESS) {
@@ -942,11 +960,11 @@ static int memory_ioctl(struct inode *inode, struct file *file,
 
     switch (cmd) {
     case BLKGETSIZE:
-	if (!IS_DIRECT(minor))
-	    put_user(dev->direct.cardsize/SECTOR_SIZE, (long *)arg);
+	if (IS_DIRECT(minor))
+	    size = dev->direct.cardsize - dev->direct.offset;
 	else
-	    put_user(minor_dev->region.RegionSize/SECTOR_SIZE,
-		     (long *)arg);
+	    size = minor_dev->region.RegionSize - minor_dev->offset;
+	put_user(size/SECTOR_SIZE, (long *)arg);
 	break;
     case MEMGETINFO:
 	if (!IS_DIRECT(minor)) {
@@ -999,7 +1017,7 @@ static void do_direct_request(dev_link_t *link)
 
     direct = &dev->direct;
     
-    addr = CURRENT->sector * SECTOR_SIZE;
+    addr = CURRENT->sector * SECTOR_SIZE + direct->offset;
     len = CURRENT->current_nr_sectors * SECTOR_SIZE;
     if ((addr + len) > direct->cardsize) {
 	end_request(0);
@@ -1007,6 +1025,7 @@ static void do_direct_request(dev_link_t *link)
     }
     
     mod.Attributes = WIN_ENABLE | WIN_MEMORY_TYPE_CM;
+    mod.Attributes |= WIN_WIDTH(word_width);
     mod.AccessSpeed = mem_speed;
     ret = CardServices(ModifyWindow, link->win, &mod);
     if (ret != CS_SUCCESS) {
@@ -1067,7 +1086,7 @@ static void do_memory_request(request_arg_t)
 	minor_dev = &dev->minor[REGION_NR(minor)];
 
 	req.Attributes = MEM_OP_BUFFER_KERNEL;
-	req.Offset = CURRENT->sector * SECTOR_SIZE;
+	req.Offset = CURRENT->sector * SECTOR_SIZE + minor_dev->offset;
 	req.Count = CURRENT->current_nr_sectors * SECTOR_SIZE;
 	buf = CURRENT->buffer;
 	ret = CS_SUCCESS;
