@@ -1,5 +1,5 @@
 /*
- * i82365.h 1.18 2000/03/08 23:37:13
+ * i82365.h 1.20 2000/07/20 23:00:27
  *
  * The contents of this file are subject to the Mozilla Public License
  * Version 1.1 (the "License"); you may not use this file except in
@@ -12,7 +12,7 @@
  * limitations under the License. 
  *
  * The initial developer of the original code is David A. Hinds
- * <dhinds@pcmcia.sourceforge.org>.  Portions created by David A. Hinds
+ * <dahinds@users.sourceforge.net>.  Portions created by David A. Hinds
  * are Copyright (C) 1999 David A. Hinds.  All Rights Reserved.
  *
  * Alternatively, the contents of this file may be used under the
@@ -97,6 +97,7 @@
 #define I365_CSC_GPI	0x10
 
 /* Flags for I365_ADDRWIN */
+#define I365_ADDR_MEMCS16	0x20
 #define I365_ENA_IO(map)	(0x40 << (map))
 #define I365_ENA_MEM(map)	(0x01 << (map))
 
