@@ -2,7 +2,7 @@
 
     Kernel fixups for PCI device support
     
-    pci_fixup.c 1.23 2000/11/07 21:15:14
+    pci_fixup.c 1.26 2001/03/16 02:27:17
     
     PCI bus fixups: various bits of code that don't really belong in
     the PCMCIA subsystem, but may or may not be available from the
@@ -246,6 +246,23 @@ static void ali_init(struct pci_dev *router, u8 link, u8 irq)
     pci_write_config_byte(router, 0x48 + ((link-1)>>1), pirq);
 }
 
+static u8 cyrix_link(struct pci_dev *router, u8 link)
+{
+    u8 pirq;
+    /* link should be 1, 2, 3, 4 */
+    pci_read_config_byte(router, 0x5c + ((link-1)>>1), &pirq);
+    return ((link & 1) ? pirq >> 4 : pirq & 15);
+}
+
+static void cyrix_init(struct pci_dev *router, u8 link, u8 irq)
+{
+    u8 pirq;
+    pci_read_config_byte(router, 0x5c + (link>>1), &pirq);
+    pirq &= (link & 1) ? 0x0f : 0xf0;
+    pirq |= (link & 1) ? (irq << 4) : (irq & 15);
+    pci_write_config_byte(router, 0x5c + (link>>1), pirq);
+}
+
 /*
   A table of all the PCI interrupt routers for which we know how to
   interpret the link bytes.
@@ -318,7 +335,8 @@ struct router {
     { ID(OPTI, 82C700),		&opti_link,	&opti_init },
     { ID(AL, M1533),		&ali_link,	&ali_init },
     { ID(SI, 503),		&pIIx_link,	&pIIx_init },
-    { ID(SI, 496),		&pIIx_link,	&pIIx_init }
+    { ID(SI, 496),		&pIIx_link,	&pIIx_init },
+    { ID(CYRIX, 5530_LEGACY),	&cyrix_link,	&cyrix_init }
 };
 #define ROUTER_COUNT (sizeof(router_table)/sizeof(router_table[0]))
 
@@ -336,7 +354,7 @@ static void scan_pirq_table(void)
     struct routing_table *r;
     struct pci_dev *router, *dev;
     u8 pin, fn, *p;
-    int i;
+    int i, j;
     struct slot_entry *e;
 
     /* Scan the BIOS for the routing table signature */
@@ -349,7 +367,13 @@ static void scan_pirq_table(void)
     pirq = r = (struct routing_table *)p;
     printk(KERN_INFO "PCI routing table version %d.%d at %#06x\n",
 	   r->major, r->minor, (u32)r & 0xfffff);
-    pci_irq_mask |= r->pci_mask;
+    for (i = j = 0; i < 16; i++)
+	j += (r->pci_mask >> i) & 1;
+    if (j > 4)
+	printk(KERN_NOTICE "  bogus PCI irq mask %#04x!\n",
+	       r->pci_mask);
+    else
+	pci_irq_mask |= r->pci_mask;
 
     router_dev = router = pci_find_slot(r->bus, r->devfn);
     if (router) {
@@ -610,6 +634,13 @@ void pci_fixup_init(void)
 
 #if (LINUX_VERSION_CODE < VERSION(2,3,24)) && defined(__i386__)
     scan_pirq_table();
+    pci_for_each_dev(p)
+	if (((p->class >> 8) == PCI_CLASS_BRIDGE_CARDBUS) &&
+	    (p->irq == 0)) break;
+    if (p && !pirq)
+	printk(KERN_INFO "No PCI interrupt routing table!\n");
+    if (!pirq && cb_pci_irq)
+	printk(KERN_INFO "cb_pci_irq will be ignored.\n");
 #endif
 
     pci_for_each_dev(p)
